@@ -8,7 +8,8 @@ import inspect
 import importlib
 import traceback
 from types import ModuleType
-from typing import Any, Callable, List, Optional, Tuple
+from typing import Any, Callable, List, Optional, Tuple, Pattern
+from typing import Match, Type
 
 
 def add_docstring_to_stubfile(
@@ -47,13 +48,154 @@ def add_docstring_to_stubfile(
             method_name=callable_name,
             module=module,
         )
+
+    class_names: List[str] = _get_top_level_class_names(
+        stub_str=stub_str)
+    class_names = _remove_doc_not_existing_class_from_class_names(
+        class_names=class_names, module=module)
+    for class_name in class_names:
+        stub_str = _add_doctring_to_target_class(
+            stub_str=stub_str,
+            class_name=class_name,
+            module=module,
+        )
+
     if not stub_str.endswith('\n'):
         stub_str += '\n'
     with open(stub_file_path, 'w') as f:
         f.write(stub_str)
 
 
+def _add_doctring_to_target_class(
+        *, stub_str: str,
+        class_name: str,
+        module: ModuleType) -> str:
+    """
+    Add a docstring to a specified class.
+
+    Parameters
+    ----------
+    stub_str : str
+        A Target stub file string.
+    class_name : str
+        A target class name.
+    module : ModuleType
+        Stub file's original module.
+
+    Returns
+    -------
+    result_stub_str : str
+        Stub file string after docstring added.
+    """
+    docstring: str = _get_docstring_from_top_level_class(
+        class_name=class_name, module=module)
+    result_docstring: str = '    """'
+    docstring_lines: List[str] = docstring.splitlines()
+    for i, docstring_line in enumerate(docstring_lines):
+        result_docstring += '\n'
+        if i == 0:
+            result_docstring += '    '
+        result_docstring += f'{docstring_line}'
+    result_docstring += '\n    """'
+
+    result_stub_str = re.sub(
+        pattern=rf'^class {class_name}(.*?)\:',
+        repl=rf'class {class_name}\1:\n{result_docstring}',
+        string=stub_str,
+        count=1,
+        flags=re.MULTILINE | re.DOTALL)
+    return result_stub_str
+
+
+def _remove_doc_not_existing_class_from_class_names(
+        *, class_names: List[str], module: ModuleType) -> List[str]:
+    """
+    Remove top-level class names from a class names list
+    that docstring does not exist.
+
+    Parameters
+    ----------
+    class_names : List[str]
+        Class names list.
+    module : ModuleType
+        A module that specified classes are defined.
+
+    Returns
+    -------
+    result_class_names : List[str]
+        A list after removing.
+    """
+    result_class_names: List[str] = []
+    for class_name in class_names:
+        docstring: str = _get_docstring_from_top_level_class(
+            class_name=class_name,
+            module=module)
+        if docstring == '':
+            continue
+        result_class_names.append(class_name)
+    return result_class_names
+
+
+def _get_docstring_from_top_level_class(
+        *, class_name: str, module: ModuleType) -> str:
+    """
+    Get a docstring from a specified top-level class.
+
+    Parameters
+    ----------
+    class_name : str
+        A target class name.
+    module : ModuleType
+        A module that a specified class is defined.
+
+    Returns
+    -------
+    docstring : str
+        An extracted class docstring.
+    """
+    members: List[Tuple[str, Type]] = inspect.getmembers(
+        object=module, predicate=inspect.isclass)
+    for member_name, member_class in members:
+        if member_name != class_name:
+            continue
+        if member_class.__doc__ is None:
+            return ''
+        docstring: str = member_class.__doc__.strip()
+        return docstring
+    return ''
+
+
+def _get_top_level_class_names(*, stub_str: str) -> List[str]:
+    """
+    Get top-level class names from a specified stub string.
+
+    Parameters
+    ----------
+    stub_str : str
+        A target stub string.
+
+    Returns
+    -------
+    class_names : List[str]
+        Extracted top-level class names.
+    """
+    class_names: List[str] = []
+    lines: List[str] = stub_str.splitlines()
+    pattern: Pattern = re.compile(pattern=r'^class (.+?)[\(\:]')
+    for line in lines:
+        match: Optional[Match] = pattern.match(string=line)
+        if match is None:
+            continue
+        class_name: str = match.group(1).strip()
+        class_names.append(class_name)
+    return class_names
+
+
 class _ClassScopeLineRange:
+    """
+    The class that stores specified class's scope line range
+    in stub string.
+    """
 
     _class_name: str
     _stub_str: str
@@ -112,12 +254,12 @@ class _ClassScopeLineRange:
 def _add_docstring_to_class_method(
         stub_str: str, method_name: str, module: ModuleType) -> str:
     """
-    Add docstring to a specified class method.
+    Add a docstring to a specified class method.
 
     Parameters
     ----------
     stub_str : str
-        Target stub file's string.
+        Target stub file string.
     method_name : str
         Target method name (top-level class method only).
         Class name and method name need to be concatenated by comma.
@@ -128,7 +270,7 @@ def _add_docstring_to_class_method(
     Returns
     -------
     result_stub_str : str
-        Stub file's string after docstring added.
+        Stub file string after docstring added.
     """
     class_name: str = method_name.split('.')[0]
     method_name = method_name.split('.')[1]
@@ -235,33 +377,33 @@ def _get_docstring_from_top_level_class_method(
 def _remove_doc_not_existing_func_from_callable_names(
         callable_names: List[str], module: ModuleType) -> List[str]:
     """
-    Remove top-level function that docstring not existing from callable
-    names list.
+    Remove top-level function names from a callable names list
+    that docstring does not exist.
 
     Parameters
     ----------
     callable_names : list of str
         Callable names list to check.
     module : ModuleType
-        The module that specified callables are defined.
+        A module that specified callables are defined.
 
     Returns
     -------
-    remove_callable_names : list of str
-        The list that removed docstring not existing functions.
+    result_callable_names : list of str
+        A list after removing.
     """
-    remove_callable_names: List[str] = []
+    result_callable_names: List[str] = []
     for callable_name in callable_names:
         if '.' in callable_name:
-            remove_callable_names.append(callable_name)
+            result_callable_names.append(callable_name)
             continue
         docstring: str = _get_docstring_from_top_level_func(
             function_name=callable_name,
             module=module)
         if docstring == '':
             continue
-        remove_callable_names.append(callable_name)
-    return remove_callable_names
+        result_callable_names.append(callable_name)
+    return result_callable_names
 
 
 def _add_doctring_to_target_function(
@@ -384,7 +526,7 @@ def _get_docstring_from_top_level_func(
         target_function: Callable = member_val
         if target_function.__doc__ is None:
             return ''
-        docstring : str = target_function.__doc__
+        docstring: str = target_function.__doc__
         docstring = docstring.strip()
         return docstring
     return ''
